@@ -117,6 +117,9 @@ request = bottle.request
 response = bottle.response
 abort = bottle.abort
 
+# monkey patching bottle/ombott
+request.query.__class__.get, request.query.__class__.getraw = request.query.__class__.getunicode, request.query.__class__.get
+
 os.environ.update(
     {key: value for key, value in DEFAULTS.items() if key not in os.environ}
 )
@@ -1584,6 +1587,11 @@ def start_server(kwargs):
         params["keyfile"] = kwargs["ssl_key"]
 
     if server_config["server"] == "gevent":
+        if kwargs['watch'] != 'off':
+            print('Error: watch doesn\'t work with gevent. ')
+            print('invoke py4web with `--watch off` or choose another server. ')
+            exit(255)
+
         if not hasattr(_ssl, "sslwrap"):
             _ssl.sslwrap = new_sslwrap
 
